package main

import (
	"crypto/aes"
	"crypto/cipher"
	"crypto/rand"
	"io"
)

func encrypt(plaintext []byte, key []byte) ([]byte, error) {

	Block, err := aes.NewCipher(key)
	checkError(err)

	GCM, err := cipher.NewGCM(Block)
	checkError(err)

	wordGCM := make([]byte, GCM.NonceSize())
	if _, err := io.ReadFull(rand.Reader, wordGCM); err != nil {
		return nil, err
	}

	ciphertext := GCM.Seal(wordGCM, wordGCM, plaintext, nil)
	return ciphertext, nil

}

func decrypt(decrypText []byte, key []byte) ([]byte, error) {

	Block, err := aes.NewCipher(key)
	checkError(err)

	GCM, err := cipher.NewGCM(Block)
	checkError(err)

	gcmNonce := GCM.NonceSize()

	nonceBlock, decrypText := decrypText[:gcmNonce], decrypText[gcmNonce:]

	plainText, err := GCM.Open(nil, nonceBlock, decrypText, nil)
	if err != nil {
		return nil, err
	}

	return plainText, err

}
